@@ -7,7 +7,7 @@
 # @Date   :  2020-10-29 13:38:36
 # @Description :  Powered by GitOPEN
 
-__version__ = "0.2.9"
+__version__ = "0.2.10"
 
 import json
 import time
@@ -18,7 +18,7 @@ from typing import Optional
 from gitopenlib.utils import basics as gb
 
 
-def new_dirs(dir_paths: str or list):
+def new_dirs(dir_paths: Optional[str or list]):
     """
     初始化文件夹，检验文件夹的存在状态，并返回准备好的文件夹路径。
 
@@ -36,7 +36,9 @@ def new_dirs(dir_paths: str or list):
 
 
 def get_paths_from_dir(
-    dirs: str or list, types: Optional[str or list] = None, recusive: bool = False
+    dirs: Optional[str or list],
+    types: Optional[str or list] = None,
+    recusive: bool = False,
 ):
     """
     从指定目录下获取所有指定扩展名文件的路径
@@ -71,8 +73,8 @@ def get_paths_from_dir(
 
 
 def file_writer(
-    lines: str or list,
-    dir_path: str or Path,
+    lines: Optional[str or list],
+    dir_path: Optional[str or Path],
     file_name: str = "file_writer.txt",
     mode: str = "a+",
     separator: str = "\n",
@@ -175,7 +177,7 @@ def read_txt_by_page(
     print(f"## All done. Total pages: {curr_page_id}. Elapsed time: {total_time}s")
 
 
-def read_content(file_path: str or PosixPath, encoding: str = "utf-8"):
+def read_content(file_path: Optional[str or PosixPath], encoding: str = "utf-8"):
     """
     从文本文件中读取内容，将内容转换为list，list的元素为每行的字符串
 
@@ -193,7 +195,7 @@ def read_content(file_path: str or PosixPath, encoding: str = "utf-8"):
     )
 
 
-def read_jsons(file_path: str or PosixPath, encoding: str = "utf-8"):
+def read_jsons(file_path: Optional[str or PosixPath], encoding: str = "utf-8"):
     """
     从存放json的文本文件中读取内容，并转化为dict组成的list
 
